@@ -6,21 +6,15 @@ use lfest::*;
 fn lin_long_market_win_full() {
     if let Err(_) = pretty_env_logger::try_init() {}
 
-    let config = Config {
-        fee_maker: 0.0,
-        fee_taker: 0.0,
-        starting_balance: 1000.0,
-        leverage: 1.0,
-        futures_type: FuturesType::Linear,
-    };
-    let fee_taker = config.fee_taker;
+    let config = Config::new(0.0002, 0.0006, 1.0, 1.0, FuturesTypes::Linear).unwrap();
+
     let mut exchange = Exchange::new(config);
-    exchange.update_state(100.0, 100.0, 0, 100.0, 100.0);
+    let _ = exchange.update_state(100.0, 100.0, 0, 100.0, 100.0);
 
     assert!(exchange
         .submit_order(Order::market(Side::Buy, 9.0).unwrap())
         .is_ok());
-    exchange.update_state(100.0, 100.0, 0, 100.0, 100.0);
+    let _ = exchange.update_state(100.0, 100.0, 0, 100.0, 100.0);
 
     assert_eq!(exchange.account().position().size(), 9.0);
     assert_eq!(exchange.account().position().entry_price(), 100.0);
@@ -29,7 +23,7 @@ fn lin_long_market_win_full() {
     assert_eq!(exchange.account().margin().position_margin(), 900.0);
     assert_eq!(exchange.account().margin().available_balance(), 100.0);
 
-    exchange.update_state(200.0, 200.0, 1, 200.0, 200.0);
+    let _ = exchange.update_state(200.0, 200.0, 1, 200.0, 200.0);
     assert_eq!(exchange.account().position().unrealized_pnl(), 900.0);
 
     assert!(exchange
